from .common import (
    copy_file_if_different as copy_file_if_different,
    download_file as download_file,
    download_mpv as download_mpv,
    download_syncplay as download_syncplay,
    generate_links as generate_links,
    get_github_release as get_github_release,
    get_movie_episode_count as get_movie_episode_count,
    get_season_episode_count as get_season_episode_count,
    remove_anime4k as remove_anime4k,
    remove_mpv_scripts as remove_mpv_scripts,
    setup_autoexit as setup_autoexit,
    setup_autostart as setup_autostart,
)
